View Source EdgeDB.Error exception (EdgeDB v0.6.0)
Exception returned by the client if an error occurred.
Most of the functions in the EdgeDB.Error module are a shorthands for simplifying EdgeDB.Error exception
constructing. These functions are generated at compile time from a copy of the
errors.txt file.
The useful ones are:
Link to this section Summary
Functions
Create a new EdgeDB.Error with EdgeDB.AccessError type.
Create a new EdgeDB.Error with EdgeDB.AccessPolicyError type.
Create a new EdgeDB.Error with EdgeDB.AuthenticationError type.
Create a new EdgeDB.Error with EdgeDB.AvailabilityError type.
Create a new EdgeDB.Error with EdgeDB.BackendError type.
Create a new EdgeDB.Error with EdgeDB.BackendUnavailableError type.
Create a new EdgeDB.Error with EdgeDB.BinaryProtocolError type.
Create a new EdgeDB.Error with EdgeDB.CapabilityError type.
Create a new EdgeDB.Error with EdgeDB.CardinalityViolationError type.
Create a new EdgeDB.Error with EdgeDB.ClientConnectionClosedError type.
Create a new EdgeDB.Error with EdgeDB.ClientConnectionError type.
Create a new EdgeDB.Error with EdgeDB.ClientConnectionFailedError type.
Create a new EdgeDB.Error with EdgeDB.ClientConnectionFailedTemporarilyError type.
Create a new EdgeDB.Error with EdgeDB.ClientConnectionTimeoutError type.
Create a new EdgeDB.Error with EdgeDB.ClientError type.
Create a new EdgeDB.Error with EdgeDB.ConfigurationError type.
Create a new EdgeDB.Error with EdgeDB.ConstraintViolationError type.
Create a new EdgeDB.Error with EdgeDB.DisabledCapabilityError type.
Create a new EdgeDB.Error with EdgeDB.DivisionByZeroError type.
Create a new EdgeDB.Error with EdgeDB.DuplicateCastDefinitionError type.
Create a new EdgeDB.Error with EdgeDB.DuplicateConstraintDefinitionError type.
Create a new EdgeDB.Error with EdgeDB.DuplicateDatabaseDefinitionError type.
Create a new EdgeDB.Error with EdgeDB.DuplicateDefinitionError type.
Create a new EdgeDB.Error with EdgeDB.DuplicateFunctionDefinitionError type.
Create a new EdgeDB.Error with EdgeDB.DuplicateLinkDefinitionError type.
Create a new EdgeDB.Error with EdgeDB.DuplicateModuleDefinitionError type.
Create a new EdgeDB.Error with EdgeDB.DuplicateOperatorDefinitionError type.
Create a new EdgeDB.Error with EdgeDB.DuplicatePropertyDefinitionError type.
Create a new EdgeDB.Error with EdgeDB.DuplicateUserDefinitionError type.
Create a new EdgeDB.Error with EdgeDB.DuplicateViewDefinitionError type.
Create a new EdgeDB.Error with EdgeDB.EdgeQLSyntaxError type.
Create a new EdgeDB.Error with EdgeDB.ExecutionError type.
Create a new EdgeDB.Error with EdgeDB.GraphQLSyntaxError type.
Create a new EdgeDB.Error with EdgeDB.IdleSessionTimeoutError type.
Create a new EdgeDB.Error with EdgeDB.IdleTransactionTimeoutError type.
Check if the exception is an inheritor of another EdgeDB error.
Create a new EdgeDB.Error with EdgeDB.InputDataError type.
Create a new EdgeDB.Error with EdgeDB.IntegrityError type.
Create a new EdgeDB.Error with EdgeDB.InterfaceError type.
Create a new EdgeDB.Error with EdgeDB.InternalClientError type.
Create a new EdgeDB.Error with EdgeDB.InternalServerError type.
Create a new EdgeDB.Error with EdgeDB.InvalidAliasDefinitionError type.
Create a new EdgeDB.Error with EdgeDB.InvalidArgumentError type.
Create a new EdgeDB.Error with EdgeDB.InvalidCastDefinitionError type.
Create a new EdgeDB.Error with EdgeDB.InvalidConstraintDefinitionError type.
Create a new EdgeDB.Error with EdgeDB.InvalidDatabaseDefinitionError type.
Create a new EdgeDB.Error with EdgeDB.InvalidDefinitionError type.
Create a new EdgeDB.Error with EdgeDB.InvalidFunctionDefinitionError type.
Create a new EdgeDB.Error with EdgeDB.InvalidLinkDefinitionError type.
Create a new EdgeDB.Error with EdgeDB.InvalidLinkTargetError type.
Create a new EdgeDB.Error with EdgeDB.InvalidModuleDefinitionError type.
Create a new EdgeDB.Error with EdgeDB.InvalidOperatorDefinitionError type.
Create a new EdgeDB.Error with EdgeDB.InvalidPropertyDefinitionError type.
Create a new EdgeDB.Error with EdgeDB.InvalidPropertyTargetError type.
Create a new EdgeDB.Error with EdgeDB.InvalidReferenceError type.
Create a new EdgeDB.Error with EdgeDB.InvalidSyntaxError type.
Create a new EdgeDB.Error with EdgeDB.InvalidTargetError type.
Create a new EdgeDB.Error with EdgeDB.InvalidTypeError type.
Create a new EdgeDB.Error with EdgeDB.InvalidUserDefinitionError type.
Create a new EdgeDB.Error with EdgeDB.InvalidValueError type.
Create a new EdgeDB.Error with EdgeDB.LogMessage type.
Create a new EdgeDB.Error with EdgeDB.MissingArgumentError type.
Create a new EdgeDB.Error with EdgeDB.MissingRequiredError type.
Create a new EdgeDB.Error with EdgeDB.NoDataError type.
Create a new EdgeDB.Error with EdgeDB.NumericOutOfRangeError type.
Create a new EdgeDB.Error with EdgeDB.ParameterTypeMismatchError type.
Create a new EdgeDB.Error with EdgeDB.ProtocolError type.
Create a new EdgeDB.Error with EdgeDB.QueryArgumentError type.
Create a new EdgeDB.Error with EdgeDB.QueryError type.
Create a new EdgeDB.Error with EdgeDB.QueryTimeoutError type.
Check if should try to reconnect to EdgeDB server.
Create a new EdgeDB.Error with EdgeDB.ResultCardinalityMismatchError type.
Check if should try to repeat the query during the execution of which an error occurred.
Create a new EdgeDB.Error with EdgeDB.SchemaDefinitionError type.
Create a new EdgeDB.Error with EdgeDB.SchemaError type.
Create a new EdgeDB.Error with EdgeDB.SchemaSyntaxError type.
Create a new EdgeDB.Error with EdgeDB.SessionTimeoutError type.
Create a new EdgeDB.Error with EdgeDB.StateMismatchError type.
Create a new EdgeDB.Error with EdgeDB.TransactionConflictError type.
Create a new EdgeDB.Error with EdgeDB.TransactionDeadlockError type.
Create a new EdgeDB.Error with EdgeDB.TransactionError type.
Create a new EdgeDB.Error with EdgeDB.TransactionSerializationError type.
Create a new EdgeDB.Error with EdgeDB.TransactionTimeoutError type.
Create a new EdgeDB.Error with EdgeDB.TypeSpecNotFoundError type.
Create a new EdgeDB.Error with EdgeDB.UnexpectedMessageError type.
Create a new EdgeDB.Error with EdgeDB.UnknownArgumentError type.
Create a new EdgeDB.Error with EdgeDB.UnknownDatabaseError type.
Create a new EdgeDB.Error with EdgeDB.UnknownLinkError type.
Create a new EdgeDB.Error with EdgeDB.UnknownModuleError type.
Create a new EdgeDB.Error with EdgeDB.UnknownParameterError type.
Create a new EdgeDB.Error with EdgeDB.UnknownPropertyError type.
Create a new EdgeDB.Error with EdgeDB.UnknownUserError type.
Create a new EdgeDB.Error with EdgeDB.UnsupportedBackendFeatureError type.
Create a new EdgeDB.Error with EdgeDB.UnsupportedCapabilityError type.
Create a new EdgeDB.Error with EdgeDB.UnsupportedFeatureError type.
Create a new EdgeDB.Error with EdgeDB.UnsupportedProtocolVersionError type.
Create a new EdgeDB.Error with EdgeDB.WarningMessage type.
Link to this section Types
Link to this section Functions
Create a new EdgeDB.Error with EdgeDB.AccessError type.
Create a new EdgeDB.Error with EdgeDB.AccessPolicyError type.
Create a new EdgeDB.Error with EdgeDB.AuthenticationError type.
Create a new EdgeDB.Error with EdgeDB.AvailabilityError type.
Create a new EdgeDB.Error with EdgeDB.BackendError type.
Create a new EdgeDB.Error with EdgeDB.BinaryProtocolError type.
Create a new EdgeDB.Error with EdgeDB.CapabilityError type.
Create a new EdgeDB.Error with EdgeDB.CardinalityViolationError type.
Create a new EdgeDB.Error with EdgeDB.ClientConnectionClosedError type.
Create a new EdgeDB.Error with EdgeDB.ClientConnectionError type.
Create a new EdgeDB.Error with EdgeDB.ClientConnectionFailedError type.
Create a new EdgeDB.Error with EdgeDB.ClientConnectionFailedTemporarilyError type.
Create a new EdgeDB.Error with EdgeDB.ClientConnectionTimeoutError type.
Create a new EdgeDB.Error with EdgeDB.ClientError type.
Create a new EdgeDB.Error with EdgeDB.ConfigurationError type.
Create a new EdgeDB.Error with EdgeDB.ConstraintViolationError type.
Create a new EdgeDB.Error with EdgeDB.DisabledCapabilityError type.
Create a new EdgeDB.Error with EdgeDB.DivisionByZeroError type.
Create a new EdgeDB.Error with EdgeDB.DuplicateCastDefinitionError type.
Create a new EdgeDB.Error with EdgeDB.DuplicateConstraintDefinitionError type.
Create a new EdgeDB.Error with EdgeDB.DuplicateDatabaseDefinitionError type.
Create a new EdgeDB.Error with EdgeDB.DuplicateDefinitionError type.
Create a new EdgeDB.Error with EdgeDB.DuplicateFunctionDefinitionError type.
Create a new EdgeDB.Error with EdgeDB.DuplicateLinkDefinitionError type.
Create a new EdgeDB.Error with EdgeDB.DuplicateModuleDefinitionError type.
Create a new EdgeDB.Error with EdgeDB.DuplicateOperatorDefinitionError type.
Create a new EdgeDB.Error with EdgeDB.DuplicatePropertyDefinitionError type.
Create a new EdgeDB.Error with EdgeDB.DuplicateUserDefinitionError type.
Create a new EdgeDB.Error with EdgeDB.DuplicateViewDefinitionError type.
Create a new EdgeDB.Error with EdgeDB.EdgeQLSyntaxError type.
Create a new EdgeDB.Error with EdgeDB.ExecutionError type.
Create a new EdgeDB.Error with EdgeDB.GraphQLSyntaxError type.
Create a new EdgeDB.Error with EdgeDB.IdleSessionTimeoutError type.
Create a new EdgeDB.Error with EdgeDB.IdleTransactionTimeoutError type.
Check if the exception is an inheritor of another EdgeDB error.
Create a new EdgeDB.Error with EdgeDB.InputDataError type.
Create a new EdgeDB.Error with EdgeDB.IntegrityError type.
Create a new EdgeDB.Error with EdgeDB.InterfaceError type.
Create a new EdgeDB.Error with EdgeDB.InternalClientError type.
Create a new EdgeDB.Error with EdgeDB.InternalServerError type.
Create a new EdgeDB.Error with EdgeDB.InvalidAliasDefinitionError type.
Create a new EdgeDB.Error with EdgeDB.InvalidArgumentError type.
Create a new EdgeDB.Error with EdgeDB.InvalidCastDefinitionError type.
Create a new EdgeDB.Error with EdgeDB.InvalidConstraintDefinitionError type.
Create a new EdgeDB.Error with EdgeDB.InvalidDatabaseDefinitionError type.
Create a new EdgeDB.Error with EdgeDB.InvalidDefinitionError type.
Create a new EdgeDB.Error with EdgeDB.InvalidFunctionDefinitionError type.
Create a new EdgeDB.Error with EdgeDB.InvalidLinkDefinitionError type.
Create a new EdgeDB.Error with EdgeDB.InvalidLinkTargetError type.
Create a new EdgeDB.Error with EdgeDB.InvalidModuleDefinitionError type.
Create a new EdgeDB.Error with EdgeDB.InvalidOperatorDefinitionError type.
Create a new EdgeDB.Error with EdgeDB.InvalidPropertyDefinitionError type.
Create a new EdgeDB.Error with EdgeDB.InvalidPropertyTargetError type.
Create a new EdgeDB.Error with EdgeDB.InvalidReferenceError type.
Create a new EdgeDB.Error with EdgeDB.InvalidSyntaxError type.
Create a new EdgeDB.Error with EdgeDB.InvalidTargetError type.
Create a new EdgeDB.Error with EdgeDB.InvalidTypeError type.
Create a new EdgeDB.Error with EdgeDB.InvalidUserDefinitionError type.
Create a new EdgeDB.Error with EdgeDB.InvalidValueError type.
Create a new EdgeDB.Error with EdgeDB.LogMessage type.
Create a new EdgeDB.Error with EdgeDB.MissingArgumentError type.
Create a new EdgeDB.Error with EdgeDB.MissingRequiredError type.
Create a new EdgeDB.Error with EdgeDB.NoDataError type.
Create a new EdgeDB.Error with EdgeDB.NumericOutOfRangeError type.
Create a new EdgeDB.Error with EdgeDB.ParameterTypeMismatchError type.
Create a new EdgeDB.Error with EdgeDB.ProtocolError type.
Create a new EdgeDB.Error with EdgeDB.QueryArgumentError type.
Create a new EdgeDB.Error with EdgeDB.QueryError type.
Create a new EdgeDB.Error with EdgeDB.QueryTimeoutError type.
@spec reconnect?(Exception.t()) :: boolean()
Check if should try to reconnect to EdgeDB server.
NOTE: this function is not used right now, because DBConnection reconnects it connection itself.
Create a new EdgeDB.Error with EdgeDB.ResultCardinalityMismatchError type.
@spec retry?(Exception.t()) :: boolean()
Check if should try to repeat the query during the execution of which an error occurred.
Create a new EdgeDB.Error with EdgeDB.SchemaDefinitionError type.
Create a new EdgeDB.Error with EdgeDB.SchemaError type.
Create a new EdgeDB.Error with EdgeDB.SchemaSyntaxError type.
Create a new EdgeDB.Error with EdgeDB.SessionTimeoutError type.
Create a new EdgeDB.Error with EdgeDB.StateMismatchError type.
Create a new EdgeDB.Error with EdgeDB.TransactionConflictError type.
Create a new EdgeDB.Error with EdgeDB.TransactionDeadlockError type.
Create a new EdgeDB.Error with EdgeDB.TransactionError type.
Create a new EdgeDB.Error with EdgeDB.TransactionSerializationError type.
Create a new EdgeDB.Error with EdgeDB.TransactionTimeoutError type.
Create a new EdgeDB.Error with EdgeDB.TypeSpecNotFoundError type.
Create a new EdgeDB.Error with EdgeDB.UnexpectedMessageError type.
Create a new EdgeDB.Error with EdgeDB.UnknownArgumentError type.
Create a new EdgeDB.Error with EdgeDB.UnknownDatabaseError type.
Create a new EdgeDB.Error with EdgeDB.UnknownLinkError type.
Create a new EdgeDB.Error with EdgeDB.UnknownModuleError type.
Create a new EdgeDB.Error with EdgeDB.UnknownParameterError type.
Create a new EdgeDB.Error with EdgeDB.UnknownPropertyError type.
Create a new EdgeDB.Error with EdgeDB.UnknownUserError type.
Create a new EdgeDB.Error with EdgeDB.UnsupportedBackendFeatureError type.
Create a new EdgeDB.Error with EdgeDB.UnsupportedCapabilityError type.
Create a new EdgeDB.Error with EdgeDB.UnsupportedFeatureError type.
Create a new EdgeDB.Error with EdgeDB.UnsupportedProtocolVersionError type.
Create a new EdgeDB.Error with EdgeDB.WarningMessage type.